@@ -39,49 +39,58 @@ set -e
 # ---------------------- cleanup ----------------------
 cleanup() {
     # cleanup on exit
-    
+
     # backup the current exit status
     currentExitValue=$?
+    echo
+    echo "*** Cleaning up before exiting..."
+    echo
     if [[ "$osName" != "Windows" ]]; then
-        # kill the xfvb
-        kill $xvfbPid    
+        # kill the xfvb if still exist
+        if [ -f /proc/$xvfbPid/status ]; then
+            echo "Killing running xvfb server (pid $xvfbPid)..."
+            kill $xvfbPid    
+        fi        
     fi
     if [ "$currentExitValue" -ne "0" ]; then
+        echo
+        echo "*** Test failed "
+        echo
         # output all possible files
         cd $workingDir
-        echo
-        echo "===== ABORTED ====="
-        echo
         # Test exist status of every file and directory otherwise the script abort and the temp directory is not removed
         if [ -f "./generated-$testDirName" ]; then
-            echo "===== ABORTED generated-$testDirName ====="
+            echo "===== FAILED generated-$testDirName ====="
             cat ./generated-$testDirName
+            echo "[FAIL] generation"
         else 
             echo "===== File $workingDir/generated-$testDirName not found ====="
         fi
         if [ -d "$testDirName/build" ]; then
             cd $testDirName/build
             if [ -f "../cmake-log" ]; then
-                echo "===== ABORTED cmake-log ====="
+                echo "===== FAILED cmake-log ====="
                 cat ../cmake-log
             else
                 echo "===== File $testDirName/build/../cmake-log not found ====="
             fi
             if [ -f "../cmake-error" ]; then
-                echo "===== ABORTED cmake-error ====="  
+                echo "===== FAILED cmake-error ====="  
                 cat ../cmake-error
+                echo "[FAIL] CMake configuration"
             else
                 echo "===== File $testDirName/build/../cmake-error not found ====="
             fi
             if [ -f "../make-log" ]; then
-            echo "===== ABORTED make-log ====="
-            cat ../make-log
+                echo "===== FAILED make-log ====="
+                cat ../make-log                
             else
                 echo "===== File $testDirName/build/../make-log not found ====="
             fi
             if [ -f "../make-error" ]; then
-            echo "===== ABORTED make-error ====="  
-            cat ../make-error
+                echo "===== FAILED make-error ====="  
+                cat ../make-error
+                echo "[FAIL] Build"
             else
                 echo "===== File $testDirName/build/../make-error not found ====="
             fi
@@ -91,6 +100,7 @@ cleanup() {
         cd
     fi
     # finally cleanup working dir
+    echo "Cleaning up working directory $workingDir..."
     rm -rf $workingDir
     # use the backup value (otherwise the result of the "rm -rf" command above will
     # be used, and that's probably always 0 !)
@@ -103,13 +113,13 @@ checkcommand() {
     if [ "$inBuild" == "0" ] ; then
         # check if current build is on windows debug version
         if ! hash ${1} 2>/dev/null; then
-            echo "Executable not found"
+            echo "[FAIL] Error: executable not found"
         else
             echo "[OK]"
         fi
     else
         if [ ! -x ${1} ] ; then 
-            echo "File not found or not executable"
+            echo "[FAIL] Error: file not found or not executable"
         else
             echo "[OK]"
         fi
@@ -118,26 +128,35 @@ checkcommand() {
 
 # ---------------------- init ----------------------
 init() {
-    echo "===== Checking camitk-dev installation... ====="
+    echo
+    echo "*** Checking configuration..."
+    echo
     exitStatus=0 # nothing bad. By convention exit 0 indicates success
     checkValueId=1 # test id starts at 1
-    scriptDir=$(dirname "$0")
-    echo "===== Script directory is $scriptDir ====="
 
-    echo "===== Creating temporary directory ====="
+    echo "===== Test script directory ====="
+    scriptDir="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
+    echo "[OK] Test script directory is $scriptDir"
+
+    echo "===== Creating temporary test directory ====="
     workingDir=$(mktemp --tmpdir -d camitk-test-tmp.XXXXXXXXXX)
-    echo "===== Temporary directory set to $workingDir ====="
+    echo "[OK] Temporary test directory set to $workingDir"
     
-    echo "===== Run with $# parameters. $1 $2 ====="
+    echo "===== Checking test parameters ====="
+    totalNbOfArguments=$#
+    nbOfParameters=$((totalNbOfArguments-1))
+    echo "[OK] Test launch with $nbOfParameters parameters: \"$1\" and \"$2\""
+
+    echo "===== CamiTK environment ====="
     if [ $# -lt 1 -o "$1" != "-inbuild" ] ; then
-        echo "===== Testing installed camitk version ====="
+        echo "[OK] Test using installed camitk version"
         inBuild=0
         # for installed camitk, just run the corresponding executables
         camitkGenerator=camitk-cepgenerator
         camitkConfig=camitk-config
     else
+        echo "[OK] Test using inbuild directory \"$2\" (source code in \"$3\")"
         # if -inbuild option is specified, then the next argument should be the build dir (as set by ${PROJECT_BINARY_DIR} by cmake
-        echo "===== Testing in build dir $2 (sources in $3) ====="
         inBuild=1
         # for in build test, use specific path for executables
         camitkGenerator=$2/bin/camitk-cepgenerator
@@ -149,60 +168,59 @@ init() {
         CMAKE_OPTIONS="$CMAKE_OPTIONS -DCMAKE_MODULE_PATH:PATH=$3/sdk/cmake/modules;$3/sdk/cmake/modules/macros"
     fi
 
-    echo "===== Check OS ====="
+    echo "===== Checking OS ====="
     unameOS=$(uname)
     if [[ "$unameOS" =~ ^MINGW64.* || "$unameOS" =~ ^MSYS_NT.* ]]; then
         osName="Windows"
     else
         osName="Linux"
     fi
-    echo "===== Uname is $unameOS ===== OS is $osName ====="
+    echo "[OK] uname is $unameOS → Test on OS $osName"
 
     if [[ "$osName" != "Windows" ]]; then
         echo "===== Configuring xvfb ====="
+        displayID=15
         # Starts the server first (to avoid a distracting warning output due to OpenGL context)
-        Xvfb :5 -screen 0 1600x1200x24 -ac +extension GLX +render -noreset -v    -fbdir $workingDir/ &
+        Xvfb :$displayID -screen 0 1600x1200x24 -ac +extension GLX +render -noreset -v -fbdir $workingDir/ &
         xvfbPid=$!
-        echo "PID of Xvfb: $xvfbPid"
-        export DISPLAY=:5
+        echo "[OK] PID of Xvfb: $xvfbPid"
+        export DISPLAY=:$displayID
         export XAUTHORITY=/dev/null
     fi    
 
     # Checking if current build is on windows debug version
-    echo "===== Checking $camitkConfig ====="
+    echo "===== Checking camitk-config ====="
     checkCamiTKConfig=$(checkcommand $camitkConfig)
-    echo $checkCamiTKConfig
     if [ "$checkCamiTKConfig" != "[OK]" ] ; then
         if [[ "$osName" == "Windows" ]]; then
             camitkConfig=$camitkConfig-debug
-            echo "===== Checking $camitkConfig ====="
+            echo "===== Checking camitk-config-debug ====="
             checkCamiTKConfig=$(checkcommand $camitkConfig)
-            echo $checkCamiTKConfig
+            echo "$checkCamiTKConfig"
         fi
+    else
+        echo "[OK] executable camitk-config found"
     fi
-    echo "===== Using $camitkConfig on $osName ====="
-    echo "===== Checking $camitkGenerator ====="
+    echo "===== camitk-config configuration ====="
+    echo "[OK] using $camitkConfig on $osName"
+
+    echo "===== Checking camitk-generator ====="
     checkCamiTKGenerator=$(checkcommand $camitkGenerator)
-    echo $checkCamiTKGenerator
     if [ "$checkCamiTKGenerator" != "[OK]" ] ; then
         if [[ "$osName" == "Windows" ]]; then
             camitkGenerator=$camitkGenerator-debug
-            echo "===== Checking $camitkGenerator ====="
+            echo "===== Checking camitk-generator-debug ====="
             checkCamiTKGenerator=$(checkcommand $camitkGenerator)
-            echo $checkCamiTKGenerator
-        fi    
+            echo "$checkCamiTKGenerator"
+        fi
+    else
+        echo "[OK] executable camitk-generator found"
     fi
-    echo "===== Using $camitkGenerator on $osName ====="
+    echo "===== camitk-generator configuration ====="
+    echo "[OK] using $camitkGenerator on $osName"
     
 }
 
-# ---------------------- generateSourceFiles ----------------------
-generateSourceFiles() {
-  echo "===== generate coreschema and C++ source files ====="
-  $scriptDir/generate-coreschema-files.sh
-  $scriptDir/generate-cpp-files.sh
-}
-
 # ---------------------- getConfig ----------------------
 getConfig() {
   $camitkConfig --config 2>/dev/null # | sed "s/QStandardPaths.*'.*'//"
@@ -217,17 +235,15 @@ getWorkingDirExtensionCount() {
 generateConfigureAndMake() {
   # generate
   testDirName=$(basename $1 .xml)
-  echo "================================================================================"
-  echo "========== generate, configure and build $testDirName... =========="
-  echo "================================================================================"
   echo
-  echo "========== generating... =========="
+  echo "*** $checkValueId.1 Generate, configure and build $testDirName..."
+  echo
+  echo "===== Generating source code from XML... ====="
   cd $workingDir
   rm -rf $testDirName
   mkdir $testDirName
   $camitkGenerator -f $1 -d $workingDir/$testDirName > ./generated-$testDirName
   if [ -s ./generated-$testDirName ] ; then
-    echo "===== cepgenerator log ====="
     cat ./generated-$testDirName
   fi
 
@@ -244,7 +260,7 @@ generateConfigureAndMake() {
   # configure
   mkdir build
   cd build
-  echo "===== configuring... ====="
+  echo "===== Configuring... ====="
   if [[ "$osName" == "Windows" ]]; then
     # use the currently supported visual studio version (64 bit) with the Debug config
     #cmake $CMAKE_OPTIONS -Wno-dev -G "Visual Studio 16 2019" -A x64 --config Debug ../$srcDirName > ../cmake-log 2> ../cmake-error
@@ -286,17 +302,19 @@ testcepfile() {
   generateConfigureAndMake $1 $3
   expectedValue="$2"
 
-  echo "========== check $1 =========="
-  
+  echo
+  echo "*** $checkValueId.2 Checking $1 installation..."
+  echo
+
   # check if everything is compiled and can be loaded
   value=$(getWorkingDirExtensionCount)
-  echo "$checkValueId- Check Number of extensions for $1: $value"
+  echo "Number of extensions for $1: $value found ($expectedValue expected)"
   echo "$(getConfig | grep "^  - \[W\] ")"
   if [ "$value" -ne "$expectedValue" ]; then
-    echo "Error: unexpected number of extensions installed in the working directory ($value != $expectedValue)"
+    echo "[FAIL] Error: unexpected number of extensions installed in the working directory ($value != $expectedValue)"
     exitStatus=$checkValueId
   else
-    echo "OK"
+    echo "[OK]"
   fi
   echo
   # increase id
@@ -312,9 +330,14 @@ testcepfile() {
 # if a problem occurs, call the clean method
 trap "cleanup" 0 INT QUIT ABRT PIPE TERM EXIT
 
+# add java to LD_LIBRARY_PATH to fix strange dependency (is it due to VTK9 package?)
+export JAVA_HOME=/usr/lib/jvm/default-java
+export LD_LIBRARY_PATH=${JAVA_HOME}/lib/:${JAVA_HOME}/lib/server/
+
 init $*
 cd $workingDir
-generateSourceFiles
+$scriptDir/generate-coreschema-files.sh
+$scriptDir/generate-cpp-files.sh
 
 #testcepfile cep.xml nrOfExpectedNewExtensions
 testcepfile actionAndComponentUsingViewerExtension.xml 2
@@ -322,7 +345,7 @@ testcepfile actionAndComponentUsingViewerExtension.xml 2
 # test that is too difficult to manage on Windows
 # TODO: describe the reason why it is not easy to perform it on Windows
 if [[ "$osName" == "Windows" ]]; then
-    echo "Windows: skip testing cep with lib"
+    echo "[OK] Windows: skip testing cep with lib"
 else
     testcepfile completeTest1.xml 3 testlib
 fi
