@@ -1,5 +1,7 @@
 #!/bin/bash
 
+echo "===== Extracting test coreschema XML files ====="
+
 # ---------------------- actionAndComponentUsingViewerExtension.xml ----------------------
 # Example taken from distributed source ./sdk/libraries/cepcoreschema/testdata/actionAndComponentUsingViewerExtension.xml
 cat <<EOF > actionAndComponentUsingViewerExtension.xml
@@ -76,7 +78,7 @@ cat <<EOF > exampleComponents.xml
     <copyright><![CDATA[/* ****************************************************************************
 $USERDEF_LICENCE_BEGIN$
 CamiTK - Computer Assisted Medical Intervention ToolKit
-(c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+(c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
         
 Visit http://camitk.imag.fr for more information
         
@@ -183,7 +185,7 @@ cat <<EOF > actionsExamplesLicence.xml
     <copyright><![CDATA[/*****************************************************************************
 $USERDEF_LICENCE_BEGIN$
 CamiTK - Computer Assisted Medical Intervention ToolKit
-(c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+(c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
         
 Visit http://camitk.imag.fr for more information
         
@@ -430,7 +432,7 @@ cat <<EOF > completeTest1.xml
   <copyright><![CDATA[/*****************************************************************************
 $USERDEF_LICENCE_BEGIN$
 CamiTK - Computer Assisted Medical Intervention ToolKit
-(c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+(c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
         
 Visit http://camitk.imag.fr for more information
         
@@ -584,17 +586,7 @@ $USERDEF_LICENCE_END$
       <dependencies>
         <dependency type="library" name="XSD"/>
         <dependency type="library" name="ITK"/>
-        <!-- remove due to cmake error
-             CMake Error at /usr/share/camitk-5.0/cmake/macros/camitk/CamiTKLibrary.cmake:412 (add_dependencies):
-               The dependency target "library-qtpropertybrowser" of target
-               "library-testlib" does not exist.
-             Call Stack (most recent call first):
-               libraries/testlib/CMakeLists.txt:6 (camitk_library)
-
-             The case of dependency to CEPLIBRARY build in CamiTK CE/ CamiTKCore  outside CAMITK_COMMUNITY_EDITION_BUILD should be
-             taken into account for recent CMake versions
-             <dependency type="cepLibrary" name="qtpropertybrowser"/>
-         -->
+        <dependency type="cepLibrary" name="qtpropertybrowser"/>
       </dependencies>
     </library>
   </libraries>
@@ -643,3 +635,5 @@ cat <<EOF > viewerExample.xml
     </viewerExtensions>
 </cep>
 EOF
+
+echo "[OK]"
\ No newline at end of file
